@@ -1,5 +1,5 @@
-#ifndef INC__WINDOWS_SYSLOG_DEFS_H
-#define INC__WINDOWS_SYSLOG_DEFS_H
+#ifndef INC_SRT_WINDOWS_SYSLOG_DEFS_H
+#define INC_SRT_WINDOWS_SYSLOG_DEFS_H
 
 #define LOG_EMERG       0
 #define LOG_ALERT       1
