@@ -94,7 +94,7 @@ class CRateEstimator
     typedef sync::steady_clock::time_point time_point;
     typedef sync::steady_clock::duration   duration;
 public:
-    CRateEstimator();
+    CRateEstimator(int family);
 
 public:
     uint64_t getInRatePeriod() const { return m_InRatePeriod; }
@@ -124,6 +124,7 @@ private:
     time_point m_tsInRateStartTime;
     uint64_t   m_InRatePeriod; // usec
     int        m_iInRateBps;   // Input Rate in Bytes/sec
+    int        m_iFullHeaderSize;
 };
 
 
@@ -140,10 +141,11 @@ public:
     /// @param [in] bytes  number of payload bytes in the sample.
     void addSample(const time_point& time, int pkts = 0, size_t bytes = 0);
 
-    /// Retrieve estimated bitrate in bytes per second
+    /// Retrieve estimated bitrate in bytes per second with 16-byte packet header.
     int getRate() const { return m_iRateBps; }
 
-    /// Retrieve estimated bitrate in bytes per second inluding the current sampling interval.
+    /// Retrieve estimated bitrate in bytes per second (with 16-byte packet header)
+    /// including the current sampling interval.
     int getCurrentRate() const;
 
 private:
@@ -190,10 +192,10 @@ private:
 
     Sample m_Samples[NUM_PERIODS];
 
-    time_point m_tsFirstSampleTime; //< Start time of the first sameple.
+    time_point m_tsFirstSampleTime; //< Start time of the first sample.
     int        m_iFirstSampleIdx;   //< Index of the first sample.
     int        m_iCurSampleIdx;     //< Index of the current sample being collected.
-    int        m_iRateBps;          // Input Rate in Bytes/sec
+    int        m_iRateBps;          //< Rate in Bytes/sec.
 };
 
 } // namespace srt
