@@ -79,6 +79,14 @@ namespace groups
             : m_stateCounter() // default init with zeros
             , m_activeMaxWeight()
             , m_standbyMaxWeight()
+            // XXX Setting AF_INET6 is a temporary solution for using rate estimator
+            // that counts a rate based on the current link's IP version. The results
+            // for links using IPv4 could be slightly falsified due to that (16 bytes
+            // more per a packet), but this makes the estimation results the same for
+            // the same data sent over the group, regardless of the IP version used
+            // for the currently active link (which in reality results in different
+            // load for the same stream, if links use different IP version).
+            , m_rateEstimate(AF_INET6)
         {
         }
 
