@@ -170,7 +170,7 @@ public:
 
     std::string str() const
     {
-        return len == 0 ? std::string() : std::string(stor);
+        return len == 0 ? std::string() : std::string(stor, len);
     }
 
     const char* c_str() const
@@ -342,6 +342,12 @@ struct CSrtConfig: CSrtMuxerConfig
     }
 
     int set(SRT_SOCKOPT optName, const void* val, int size);
+
+    bool payloadSizeFits(size_t val, int ip_family, std::string& w_errmsg) ATR_NOTHROW;
+
+    // This function returns the number of bytes that are allocated
+    // for a single packet in the sender and receiver buffer.
+    int bytesPerPkt() const { return iMSS - int(CPacket::UDP_HDR_SIZE); }
 };
 
 template <typename T>
@@ -379,6 +385,9 @@ inline bool cast_optval(const void* optval, int optlen)
     return false;
 }
 
+
+int RcvBufferSizeOptionToValue(int optval, int flightflag, int mss);
+
 } // namespace srt
 
 struct SRT_SocketOptionObject
