@@ -257,8 +257,16 @@ protected:
     {
         // Code here will be called just after the test completes.
         // OK to throw exceptions from here if needed.
-        EXPECT_NE(srt_close(m_caller_socket),   SRT_ERROR) << srt_getlasterror_str();
-        EXPECT_NE(srt_close(m_listener_socket), SRT_ERROR) << srt_getlasterror_str();
+
+        if (m_caller_socket != SRT_INVALID_SOCK)
+        {
+            EXPECT_NE(srt_close(m_caller_socket),   SRT_ERROR) << srt_getlasterror_str();
+        }
+
+        if (m_listener_socket != SRT_INVALID_SOCK)
+        {
+            EXPECT_NE(srt_close(m_listener_socket), SRT_ERROR) << srt_getlasterror_str();
+        }
     }
 
 
@@ -541,6 +549,7 @@ public:
             // Just give it some time and close the socket.
             std::this_thread::sleep_for(std::chrono::milliseconds(50));
             ASSERT_NE(srt_close(m_listener_socket), SRT_ERROR);
+            m_listener_socket = SRT_INVALID_SOCK; // mark closed already
             accepting_thread.join();
         }
     }
@@ -581,7 +590,7 @@ static std::ostream& PrintEpollEvent(std::ostream& os, int events, int et_events
         make_pair(SRT_EPOLL_UPDATE, "U")
     };
 
-    int N = Size(namemap);
+    const int N = (int)Size(namemap);
 
     for (int i = 0; i < N; ++i)
     {
