@@ -48,9 +48,15 @@ public:
         ASSERT_EQ(inet_pton(AF_INET, "127.0.0.1", &bind_sa.sin_addr), 1);
         bind_sa.sin_port = htons(5555);
 
+        // NOTE: listener callback must be set BEFORE LISTENING,
+        // otherwise it may potentially change the procedure in the middle of processing
+        // of an incoming connection.
+        ASSERT_NE(srt_listen_callback(server_sock, &SrtTestListenCallback, NULL), -1);
         ASSERT_NE(srt_bind(server_sock, (sockaddr*)&bind_sa, sizeof bind_sa), -1);
         ASSERT_NE(srt_listen(server_sock, 5), -1);
-        (void)srt_listen_callback(server_sock, &SrtTestListenCallback, NULL);
+
+        // Check also changing the listener callback AFTER listening - this is expected to fail.
+        ASSERT_EQ(srt_listen_callback(server_sock, &SrtTestListenCallback, NULL), -1);
 
         accept_thread = std::thread([this] { this->AcceptLoop(); });
 
@@ -210,7 +216,7 @@ int SrtTestListenCallback(void* opaq, SRTSOCKET ns, int hsversion, const struct
 
 #if SRT_ENABLE_ENCRYPTION
     cerr << "TEST: Setting password '" << exp_pw << "' as per user '" << username << "'\n";
-    EXPECT_EQ(srt_setsockflag(ns, SRTO_PASSPHRASE, exp_pw.c_str(), exp_pw.size()), SRT_SUCCESS);
+    EXPECT_EQ(srt_setsockflag(ns, SRTO_PASSPHRASE, exp_pw.c_str(), (int)exp_pw.size()), SRT_SUCCESS);
 #endif
 
     // Checking that SRTO_RCVLATENCY (PRE option) can be altered in the listener callback.
@@ -238,9 +244,9 @@ TEST_F(ListenerCallback, SecureSuccess)
     string username_spec = "#!::u=admin";
     string password = "thelocalmanager";
 
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), username_spec.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), (int)username_spec.size()), -1);
 #if SRT_ENABLE_ENCRYPTION
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), password.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), (int)password.size()), -1);
 #endif
 
     // EXPECTED RESULT: connected successfully
@@ -255,8 +261,8 @@ TEST_F(ListenerCallback, FauxPass)
     string username_spec = "#!::u=admin";
     string password = "thelokalmanager"; // (typo :D)
 
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), username_spec.size()), -1);
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), password.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), (int)username_spec.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), (int)password.size()), -1);
 
     // EXPECTED RESULT: connection rejected
     EXPECT_EQ(srt_connect(client_sock, psa, sizeof sa), SRT_ERROR);
@@ -270,9 +276,9 @@ TEST_F(ListenerCallback, FauxUser)
     string username_spec = "#!::u=haivision";
     string password = "thelocalmanager"; // (typo :D)
 
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), username_spec.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), (int)username_spec.size()), -1);
 #if SRT_ENABLE_ENCRYPTION
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), password.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), (int)password.size()), -1);
 #endif
 
     // EXPECTED RESULT: connection rejected
@@ -286,9 +292,9 @@ TEST_F(ListenerCallback, FauxSyntax)
     string username_spec = "#!::r=mystream,t=publish"; // No 'u' key specified
     string password = "thelocalmanager";
 
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), username_spec.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_STREAMID, username_spec.c_str(), (int)username_spec.size()), -1);
 #if SRT_ENABLE_ENCRYPTION
-    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), password.size()), -1);
+    ASSERT_NE(srt_setsockflag(client_sock, SRTO_PASSPHRASE, password.c_str(), (int)password.size()), -1);
 #endif
 
     // EXPECTED RESULT: connection rejected
