@@ -2,6 +2,8 @@
 #include "common.h"
 #include "core.h"
 
+using namespace srt;
+
 
 const int32_t CSeqNo::m_iSeqNoTH;
 const int32_t CSeqNo::m_iMaxSeqNo;
@@ -14,7 +16,6 @@ TEST(CSeqNo, constants)
     EXPECT_EQ(CSeqNo::m_iSeqNoTH,  0x3FFFFFFF);
 }
 
-
 TEST(CSeqNo, seqcmp)
 {
     // Compare two seq#, considering the wraping.
@@ -25,11 +26,10 @@ TEST(CSeqNo, seqcmp)
     EXPECT_EQ(CSeqNo::seqcmp(1, 128), -127);
 
     // abs(seq1 - seq2) >= 0x3FFFFFFF : seq2 - seq1
-    EXPECT_EQ(CSeqNo::seqcmp(0x7FFFFFFF, 1), 0x80000002);   // -2147483646
+    EXPECT_EQ(CSeqNo::seqcmp(0x7FFFFFFF, 1), int(0x80000002));   // -2147483646
     EXPECT_EQ(CSeqNo::seqcmp(1, 0x7FFFFFFF), 0x7FFFFFFE);   //  2147483646
 }
 
-
 TEST(CSeqNo, seqoff)
 {
     // seqoff: offset from the 2nd to the 1st seq#
@@ -46,6 +46,9 @@ TEST(CSeqNo, seqlen)
 {
     EXPECT_EQ(CSeqNo::seqlen(125, 125), 1);
     EXPECT_EQ(CSeqNo::seqlen(125, 126), 2);
+
+    EXPECT_EQ(CSeqNo::seqlen(2147483647, 0), 2);
+    EXPECT_EQ(CSeqNo::seqlen(0, 2147483647), -2147483648);
 }
 
 TEST(CUDT, getFlightSpan)
@@ -72,7 +75,6 @@ TEST(CSeqNo, incseq)
     EXPECT_EQ(CSeqNo::incseq(0x3FFFFFFF), 0x40000000);
 }
 
-
 TEST(CSeqNo, decseq)
 {
     // decseq: decrease the seq# by 1
@@ -82,7 +84,6 @@ TEST(CSeqNo, decseq)
     EXPECT_EQ(CSeqNo::decseq(0x40000000), 0x3FFFFFFF);
 }
 
-
 TEST(CSeqNo, incseqint)
 {
     // incseq: increase the seq# by 1
@@ -96,7 +97,6 @@ TEST(CSeqNo, incseqint)
     EXPECT_EQ(CSeqNo::incseq(0x3FFFFFFF, 0x40000001), 0x00000000);
 }
 
-
 TEST(CSeqNo, decseqint)
 {
     // decseq: decrease the seq# by 1
@@ -105,4 +105,3 @@ TEST(CSeqNo, decseqint)
     EXPECT_EQ(CSeqNo::decseq(0, 1),          0x7FFFFFFF);
     EXPECT_EQ(CSeqNo::decseq(0x40000000, 1), 0x3FFFFFFF);
 }
-
