@@ -10,6 +10,7 @@
  *             Haivision Systems Inc.
  */
 
+#include <array>
 #include <future>
 #include <thread>
 #include <string>
@@ -70,6 +71,9 @@ public:
         };
         auto accept_res = async(launch::async, accept_async, m_listen_sock);
 
+        // Make sure the thread was kicked
+        this_thread::yield();
+
         const int connect_res = Connect();
         EXPECT_EQ(connect_res, SRT_SUCCESS);
 
@@ -188,9 +192,12 @@ const OptionTestEntry g_test_matrix_options[] =
     { SRTO_LATENCY,             "SRTO_LATENCY", RestrictionType::PRE,     sizeof(int),                 0, INT32_MAX,      120,          200,  {-1} },
     //SRTO_LINGER
     { SRTO_LOSSMAXTTL,       "SRTO_LOSSMAXTTL", RestrictionType::POST,    sizeof(int),                 0, INT32_MAX,        0,           10,   {} },
-    //SRTO_MAXBW
+    { SRTO_MAXBW,                 "SRTO_MAXBW", RestrictionType::POST, sizeof(int64_t),      int64_t(-1),  INT64_MAX, int64_t(-1), int64_t(200000),  {int64_t(-2)}},
+#ifdef ENABLE_MAXREXMITBW
+    { SRTO_MAXREXMITBW,      "SRTO_MAXREXMITBW", RestrictionType::POST, sizeof(int64_t),     int64_t(-1), INT64_MAX,  int64_t(-1), int64_t(200000),  {int64_t(-2)}},
+#endif
     { SRTO_MESSAGEAPI,       "SRTO_MESSAGEAPI", RestrictionType::PRE,    sizeof(bool),             false,      true,     true,        false,     {} },
-    //SRTO_MININPUTBW
+    { SRTO_MININPUTBW,       "SRTO_MININPUTBW", RestrictionType::POST, sizeof(int64_t),       int64_t(0),  INT64_MAX,  int64_t(0), int64_t(200000),  {int64_t(-1)}},
     { SRTO_MINVERSION,       "SRTO_MINVERSION", RestrictionType::PRE,     sizeof(int),                 0,  INT32_MAX, 0x010000,    0x010300,    {} },
     { SRTO_MSS,                     "SRTO_MSS", RestrictionType::PREBIND, sizeof(int),                76,     65536,     1500,        1400,    {-1, 0, 75} },
     { SRTO_NAKREPORT,         "SRTO_NAKREPORT", RestrictionType::PRE,    sizeof(bool),             false,      true,     true,        false,     {} },
@@ -234,12 +241,12 @@ template<class ValueType>
 void CheckGetSockOpt(const OptionTestEntry& entry, SRTSOCKET sock, const ValueType& value, const char* desc)
 {
     ValueType opt_val;
-    int opt_len = 0;
+    int opt_len = (int) entry.opt_len;
     EXPECT_EQ(srt_getsockopt(sock, 0, entry.optid, &opt_val, &opt_len), SRT_SUCCESS)
         << "Getting " << entry.optname << " returned error: " << srt_getlasterror_str();
 
     EXPECT_EQ(opt_val, value) << desc << ": Wrong " << entry.optname << " value " << opt_val;
-    EXPECT_EQ(opt_len, entry.opt_len) << desc << "Wrong " << entry.optname << " value length";
+    EXPECT_EQ(opt_len, (int) entry.opt_len) << desc << "Wrong " << entry.optname << " value length";
 }
 
 typedef char const* strptr;
@@ -251,15 +258,15 @@ void CheckGetSockOpt<strptr>(const OptionTestEntry& entry, SRTSOCKET sock, const
     EXPECT_EQ(srt_getsockopt(sock, 0, entry.optid, &opt_val, &opt_len), SRT_SUCCESS)
         << "Getting " << entry.optname << " returned error: " << srt_getlasterror_str();
 
-    EXPECT_EQ(strncmp(opt_val, value, min<int>(opt_len, entry.opt_len)), 0) << desc << ": Wrong " << entry.optname << " value " << opt_val;
-    EXPECT_EQ(opt_len, entry.opt_len) << desc << "Wrong " << entry.optname << " value length";
+    EXPECT_EQ(strncmp(opt_val, value, min(opt_len, (int)entry.opt_len)), 0) << desc << ": Wrong " << entry.optname << " value " << opt_val;
+    EXPECT_EQ(opt_len, (int) entry.opt_len) << desc << "Wrong " << entry.optname << " value length";
 }
 
 template<class ValueType>
 void CheckSetSockOpt(const OptionTestEntry& entry, SRTSOCKET sock, const ValueType& value, int expect_return, const char* desc)
 {
     ValueType opt_val = value;
-    int opt_len = entry.opt_len;
+    int opt_len = (int)entry.opt_len;
     EXPECT_EQ(srt_setsockopt(sock, 0, entry.optid, &opt_val, opt_len), expect_return)
         << "Setting " << entry.optname << " to " << opt_val << " must " << (expect_return == SRT_SUCCESS ? "succeed" : "fail");
 
@@ -850,6 +857,29 @@ TEST_F(TestSocketOptions, StreamIDWrongLen)
     EXPECT_EQ(srt_getlasterror(NULL), SRT_EINVPARAM);
 }
 
+//Check if setting -1 as optlen returns an error 
+TEST_F(TestSocketOptions, StringOptLenInvalid)
+{
+    const string test_string = "test1234567";
+    const string srto_congestion_string ="live";
+    const string fec_config = "fec,cols:10,rows:10";
+
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, test_string.c_str(), -1), SRT_ERROR);
+    EXPECT_EQ(srt_getlasterror(NULL), SRT_EINVPARAM);
+
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_BINDTODEVICE, test_string.c_str(), -1), SRT_ERROR);
+    EXPECT_EQ(srt_getlasterror(NULL), SRT_EINVPARAM);
+
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_CONGESTION, srto_congestion_string.c_str(), -1), SRT_ERROR);
+    EXPECT_EQ(srt_getlasterror(NULL), SRT_EINVPARAM);
+
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_PACKETFILTER, fec_config.c_str(), -1), SRT_ERROR);
+    EXPECT_EQ(srt_getlasterror(NULL), SRT_EINVPARAM);
+
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_PASSPHRASE, test_string.c_str(), -1), SRT_ERROR);
+    EXPECT_EQ(srt_getlasterror(NULL), SRT_EINVPARAM);
+}
+
 // Try to set/get a 13-character string in SRTO_STREAMID.
 // This tests checks that the StreamID is set to the correct size
 // while it is transmitted as 16 characters in the Stream ID HS extension.
@@ -858,7 +888,7 @@ TEST_F(TestSocketOptions, StreamIDOdd)
     // 13 characters, that is, 3*4+1
     string sid_odd = "something1234";
 
-    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_odd.c_str(), sid_odd.size()), SRT_SUCCESS);
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_odd.c_str(), (int)sid_odd.size()), SRT_SUCCESS);
 
     char buffer[CSrtConfig::MAX_SID_LENGTH + 135];
     int buffer_len = sizeof buffer;
@@ -887,7 +917,7 @@ TEST_F(TestSocketOptions, StreamIDEven)
     // 12 characters = 4*3, that is, aligned to 4
     string sid_even = "123412341234";
 
-    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_even.c_str(), sid_even.size()), SRT_SUCCESS);
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_even.c_str(), (int)sid_even.size()), SRT_SUCCESS);
 
     char buffer[CSrtConfig::MAX_SID_LENGTH + 135];
     int buffer_len = sizeof buffer;
@@ -910,39 +940,40 @@ TEST_F(TestSocketOptions, StreamIDEven)
     ASSERT_NE(srt_close(accepted_sock), SRT_ERROR);
 }
 
-
+// Test handling of StreamID with length close to the maximum allowed.
+// Also tests the proper handling of a null character in the middle of the StreamID.
 TEST_F(TestSocketOptions, StreamIDAlmostFull)
 {
     // 12 characters = 4*3, that is, aligned to 4
-    string sid_amost_full;
-    for (size_t i = 0; i < CSrtConfig::MAX_SID_LENGTH-2; ++i)
-        sid_amost_full += 'x';
+    std::array<char, CSrtConfig::MAX_SID_LENGTH - 2> sid_almost_full;
+    const size_t size = sid_almost_full.size();
+    for (size_t i = 0; i < size; ++i)
+        sid_almost_full[i] += 'x';
 
     // Just to manipulate the last ones.
-    size_t size = sid_amost_full.size();
-    sid_amost_full[size-2] = 'y';
-    sid_amost_full[size-1] = 'z';
+    sid_almost_full[size-2] = '\0';
+    sid_almost_full[size-1] = 'z';
 
-    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_amost_full.c_str(), sid_amost_full.size()), SRT_SUCCESS);
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_almost_full.data(), (int)size), SRT_SUCCESS);
 
-    char buffer[CSrtConfig::MAX_SID_LENGTH + 135];
-    int buffer_len = sizeof buffer;
+    std::array<char, CSrtConfig::MAX_SID_LENGTH + 135> buffer;
+    int buffer_len = (int) buffer.size();
     EXPECT_EQ(srt_getsockopt(m_caller_sock, 0, SRTO_STREAMID, &buffer, &buffer_len), SRT_SUCCESS);
-    EXPECT_EQ(std::string(buffer), sid_amost_full);
-    EXPECT_EQ(size_t(buffer_len), sid_amost_full.size());
-    EXPECT_EQ(strlen(buffer), sid_amost_full.size());
+    EXPECT_EQ(size_t(buffer_len), sid_almost_full.size());
+    EXPECT_EQ(std::memcmp(buffer.data(), sid_almost_full.data(), buffer_len), 0);
 
     StartListener();
     const SRTSOCKET accepted_sock = EstablishConnection();
 
     // Check accepted socket inherits values
-    for (size_t i = 0; i < sizeof buffer; ++i)
+    buffer_len = (int) buffer.size();
+    for (int i = 0; i < buffer_len; ++i)
         buffer[i] = 'a';
-    buffer_len = (int)(sizeof buffer);
     EXPECT_EQ(srt_getsockopt(accepted_sock, 0, SRTO_STREAMID, &buffer, &buffer_len), SRT_SUCCESS);
-    EXPECT_EQ(size_t(buffer_len), sid_amost_full.size());
-    EXPECT_EQ(strlen(buffer), sid_amost_full.size());
-    EXPECT_EQ(buffer[sid_amost_full.size()-1], 'z');
+    EXPECT_EQ(size_t(buffer_len), sid_almost_full.size());
+    EXPECT_EQ(std::memcmp(buffer.data(), sid_almost_full.data(), buffer_len), 0);
+    EXPECT_EQ(buffer[sid_almost_full.size() - 2], '\0');
+    EXPECT_EQ(buffer[sid_almost_full.size() - 1], 'z');
 
     ASSERT_NE(srt_close(accepted_sock), SRT_ERROR);
 }
@@ -959,7 +990,7 @@ TEST_F(TestSocketOptions, StreamIDFull)
     sid_full[size-2] = 'y';
     sid_full[size-1] = 'z';
 
-    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_full.c_str(), sid_full.size()), SRT_SUCCESS);
+    EXPECT_EQ(srt_setsockopt(m_caller_sock, 0, SRTO_STREAMID, sid_full.c_str(), (int)sid_full.size()), SRT_SUCCESS);
 
     char buffer[CSrtConfig::MAX_SID_LENGTH + 135];
     int buffer_len = sizeof buffer;
@@ -989,7 +1020,7 @@ TEST_F(TestSocketOptions, StreamIDLenListener)
 {
     string stream_id_13 = "something1234";
 
-    EXPECT_EQ(srt_setsockopt(m_listen_sock, 0, SRTO_STREAMID, stream_id_13.c_str(), stream_id_13.size()), SRT_SUCCESS);
+    EXPECT_EQ(srt_setsockopt(m_listen_sock, 0, SRTO_STREAMID, stream_id_13.c_str(), (int)stream_id_13.size()), SRT_SUCCESS);
 
     char buffer[648];
     int buffer_len = sizeof buffer;
