@@ -160,11 +160,11 @@ TEST(CircularBuffer, Overall)
     ASSERT_EQ(output.d, 22.1);
 
     IF_HEAVY_LOGGING(cerr << "Pushing 1 aslong there is capacity:\n");
-    int i = 0;
+    IF_HEAVY_LOGGING(int i = 0);
     while (buf.push(1) != -1)
     {
         IF_HEAVY_LOGGING(cerr << "Pushed, begin=" << buf.m_xBegin << " end=" << buf.m_xEnd << endl);
-        ++i;
+        IF_HEAVY_LOGGING(++i);
     }
     IF_HEAVY_LOGGING(cerr << "Done " << i << " operations, buffer:\n");
     IF_HEAVY_LOGGING(ShowCircularBuffer(buf));
@@ -178,7 +178,7 @@ TEST(CircularBuffer, Overall)
     int offset = 9;
     IF_HEAVY_LOGGING(cerr << "Forced adding at position 9 with dropping (capacity: " << buf.capacity() << "):\n");
     // State we already know it has failed. Calculate drop size.
-    int dropshift = offset - (buf.capacity() - 1); // buf.capacity()-1 is the latest position
+    int dropshift = offset - int(buf.capacity() - 1); // buf.capacity()-1 is the latest position
     offset -= dropshift;
     IF_HEAVY_LOGGING(cerr << "Need to drop: " << dropshift << " New offset:" << offset << endl);
     ASSERT_GE(dropshift, 0);
