@@ -42,6 +42,10 @@
 
 srt_logging::Logger applog(SRT_LOGFA_APP, srt_logger_config, "srt-mpbond");
 
+using namespace srt;
+using namespace std;
+
+
 volatile bool mpbond_int_state = false;
 void OnINT_SetIntState(int)
 {
@@ -49,9 +53,6 @@ void OnINT_SetIntState(int)
     mpbond_int_state = true;
 }
 
-using namespace srt;
-
-
 int main( int argc, char** argv )
 {
     // This is mainly required on Windows to initialize the network system,
@@ -188,10 +189,7 @@ int main( int argc, char** argv )
 
         SRTSOCKET s = srt_create_socket();
 
-        //SRT_GROUPCONNTYPE gcon = SRTGC_GROUPONLY;
-        int gcon = 1;
-        srt_setsockflag(s, SRTO_GROUPCONNECT, &gcon, sizeof gcon);
-
+        srt::setopt(s)[SRTO_GROUPCONNECT] = 1;
         srt_bind(s, sa.get(), sizeof sa);
         srt_listen(s, 5);
 
@@ -201,14 +199,13 @@ int main( int argc, char** argv )
 
     Verb() << "] accept...";
 
-    SRTSOCKET conngrp = srt_accept_bond(listeners.data(), listeners.size(), -1);
+    SRTSOCKET conngrp = srt_accept_bond(listeners.data(), int(listeners.size()), -1);
     if (conngrp == SRT_INVALID_SOCK)
     {
         cerr << "ERROR: srt_accept_bond: " << srt_getlasterror_str() << endl;
         return 1;
     }
 
-    auto s = new SrtSource;
     unique_ptr<Source> src;
     unique_ptr<Target> tar;
 
@@ -221,6 +218,7 @@ int main( int argc, char** argv )
             Verb() << "SRT -> " << outspec;
             tar = Target::Create(outspec);
 
+            auto s = new SrtSource;
             s->Acquire(conngrp);
             src.reset(s);
         }
