@@ -45,6 +45,7 @@ written by
 #include "threadname.h"
 
 
+using namespace std;
 
 
 bool Upload(UriParser& srt, UriParser& file);
@@ -319,7 +320,7 @@ SrtMainLoop::SrtMainLoop(const string& srt_uri, bool input_echoback, const strin
         Verb() << "Setting up output: " << spec;
         unique_ptr<TargetMedium> m { new TargetMedium };
         m->Setup(Target::Create(spec));
-        m_output_media.push_back(move(m));
+        m_output_media.push_back(std::move(m));
     }
 
 
@@ -366,9 +367,9 @@ SrtMainLoop::SrtMainLoop(const string& srt_uri, bool input_echoback, const strin
         Verb() << "SRT set up as input source and the first output target";
 
         // Add SRT medium to output targets, and keep input medium empty.
-        unique_ptr<TargetMedium> m { new TargetMedium };
-        m->Setup(m_srt_relay.get());
-        m_output_media.push_back(move(m));
+        unique_ptr<TargetMedium> med { new TargetMedium };
+        med->Setup(m_srt_relay.get());
+        m_output_media.push_back(std::move(med));
     }
     else
     {
