@@ -20,7 +20,6 @@
 #include <map>
 #include <chrono>
 #include <thread>
-#include <atomic>
 #include <srt.h>
 #if !defined(_WIN32)
 #include <sys/ioctl.h>
@@ -50,8 +49,8 @@ using srt_logging::SockStatusStr;
 using srt_logging::MemberStatusStr;
 #endif
 
-std::atomic<bool> transmit_throw_on_interrupt {false};
-std::atomic<bool> transmit_int_state {false};
+srt::sync::atomic<bool> transmit_throw_on_interrupt {false};
+srt::sync::atomic<bool> transmit_int_state {false};
 int transmit_bw_report = 0;
 unsigned transmit_stats_report = 0;
 size_t transmit_chunk_size = SRT_LIVE_DEF_PLSIZE;
@@ -348,7 +347,7 @@ void SrtCommon::InitParameters(string host, string path, map<string,string> par)
                 }
 
                 cc.token = token++;
-                m_group_nodes.push_back(move(cc));
+                m_group_nodes.push_back(std::move(cc));
             }
 
             par.erase("type");
@@ -639,7 +638,7 @@ static string PrintEpollEvent(int events, int et_events)
     };
 
     ostringstream os;
-    int N = Size(namemap);
+    int N = (int)Size(namemap);
 
     for (int i = 0; i < N; ++i)
     {
@@ -963,16 +962,36 @@ void TransmitGroupSocketConnect(void* srtcommon, SRTSOCKET sock, int error, cons
     Verb() << " IPE: LINK NOT FOUND???]";
 }
 
+SRT_GROUP_TYPE ResolveGroupType(const string& name)
+{
+    static struct
+    {
+        string name;
+        SRT_GROUP_TYPE type;
+    } table [] {
+#define E(n) {#n, SRT_GTYPE_##n}
+        E(BROADCAST),
+        E(BACKUP)
+
+#undef E
+    };
+
+    typedef int charxform(int c);
+
+    string uname;
+    transform(name.begin(), name.end(), back_inserter(uname), (charxform*)(&toupper));
+
+    for (auto& x: table)
+        if (x.name == uname)
+            return x.type;
+
+    return SRT_GTYPE_UNDEFINED;
+}
+
 void SrtCommon::OpenGroupClient()
 {
-    SRT_GROUP_TYPE type = SRT_GTYPE_UNDEFINED;
-
-    // Resolve group type.
-    if (m_group_type == "broadcast")
-        type = SRT_GTYPE_BROADCAST;
-    else if (m_group_type == "backup")
-        type = SRT_GTYPE_BACKUP;
-    else
+    SRT_GROUP_TYPE type = ResolveGroupType(m_group_type);
+    if (type == SRT_GTYPE_UNDEFINED)
     {
         Error("With //group, type='" + m_group_type + "' undefined");
     }
@@ -1039,8 +1058,8 @@ void SrtCommon::OpenGroupClient()
         if (!extras.empty())
         {
             Verb() << "?" << extras[0] << VerbNoEOL;
-            for (size_t i = 1; i < extras.size(); ++i)
-                Verb() << "&" << extras[i] << VerbNoEOL;
+            for (size_t ii = 1; ii < extras.size(); ++ii)
+                Verb() << "&" << extras[ii] << VerbNoEOL;
         }
 
         Verb();
@@ -1059,7 +1078,7 @@ void SrtCommon::OpenGroupClient()
 Connect_Again:
         Verb() << "Waiting for group connection... " << VerbNoEOL;
 
-        int fisock = srt_connect_group(m_sock, targets.data(), targets.size());
+        int fisock = srt_connect_group(m_sock, targets.data(), int(targets.size()));
 
         if (fisock == SRT_ERROR)
         {
@@ -1110,15 +1129,15 @@ Connect_Again:
     // spread the setting on all sockets.
     ConfigurePost(m_sock);
 
-    for (size_t i = 0; i < targets.size(); ++i)
+    for (size_t j = 0; j < targets.size(); ++j)
     {
         // As m_group_nodes is simply transformed into 'targets',
         // one index can be used to index them all. You don't
         // have to check if they have equal addresses because they
         // are equal by definition.
-        if (targets[i].id != -1 && targets[i].errorcode == SRT_SUCCESS)
+        if (targets[j].id != -1 && targets[j].errorcode == SRT_SUCCESS)
         {
-            m_group_nodes[i].socket = targets[i].id;
+            m_group_nodes[j].socket = targets[j].id;
         }
     }
 
@@ -1139,9 +1158,9 @@ Connect_Again:
     }
     m_group_data.resize(size);
 
-    for (size_t i = 0; i < m_group_nodes.size(); ++i)
+    for (size_t j = 0; j < m_group_nodes.size(); ++j)
     {
-        SRTSOCKET insock = m_group_nodes[i].socket;
+        SRTSOCKET insock = m_group_nodes[j].socket;
         if (insock == -1)
         {
             Verb() << "TARGET '" << sockaddr_any(targets[i].peeraddr).str() << "' connection failed.";
@@ -1174,11 +1193,11 @@ Connect_Again:
                     NULL, NULL) != -1)
         {
             Verb() << "[C]" << VerbNoEOL;
-            for (int i = 0; i < len1; ++i)
-                Verb() << " " << ready_conn[i] << VerbNoEOL;
+            for (int ii = 0; ii < len1; ++ii)
+                Verb() << " " << ready_conn[ii] << VerbNoEOL;
             Verb() << "[E]" << VerbNoEOL;
-            for (int i = 0; i < len2; ++i)
-                Verb() << " " << ready_err[i] << VerbNoEOL;
+            for (int ii = 0; ii < len2; ++ii)
+                Verb() << " " << ready_err[ii] << VerbNoEOL;
 
             Verb() << "";
 
@@ -2304,7 +2323,7 @@ MediaPacket SrtSource::Read(size_t chunk)
             Error("srt_recvmsg2: interrupted");
 
         ::transmit_throw_on_interrupt = true;
-        stat = srt_recvmsg2(m_sock, data.data(), chunk, &mctrl);
+        stat = srt_recvmsg2(m_sock, data.data(), int(chunk), &mctrl);
         ::transmit_throw_on_interrupt = false;
         if (stat != SRT_ERROR)
         {
@@ -2500,7 +2519,7 @@ Epoll_again:
         mctrl.srctime = data.time;
     }
 
-    int stat = srt_sendmsg2(m_sock, data.payload.data(), data.payload.size(), &mctrl);
+    int stat = srt_sendmsg2(m_sock, data.payload.data(), int(data.payload.size()), &mctrl);
 
     // For a socket group, the error is reported only
     // if ALL links from the group have failed to perform
@@ -2956,7 +2975,7 @@ UdpTarget::UdpTarget(string host, int port, const map<string,string>& attr)
 
 void UdpTarget::Write(const MediaPacket& data)
 {
-    int stat = sendto(m_sock, data.payload.data(), data.payload.size(), 0, (sockaddr*)&sadr, sizeof sadr);
+    int stat = sendto(m_sock, data.payload.data(), int(data.payload.size()), 0, (sockaddr*)&sadr, int(sizeof sadr));
     if (stat == -1)
         Error(SysError(), "UDP Write/sendto");
 }
@@ -3022,7 +3041,7 @@ extern unique_ptr<Base> CreateMedium(const string& uri)
     }
 
     if (ptr)
-        ptr->uri = move(u);
+        ptr->uri = std::move(u);
     return ptr;
 }
 
